#ifndef KBLINSELCONFIG_H
#define KBLINSELCONFIG_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <qwidget.h>
#include <kfiledialog.h>
#include <qlabel.h>
#include <qstring.h>
#include <kmsgbox.h>
#include <kconfig.h>
#include <klined.h>
#include <qpushbutton.h>
#include <qstring.h>
#include <ktabctl.h>
#include <qcheckbox.h>


class KBlinselConfig : public QWidget
{
	Q_OBJECT
public:
	KBlinselConfig(KConfig *config);
	virtual ~KBlinselConfig();
public slots:
	void ok_pressed(void);
	void cancel_pressed(void);
	void browse_pressed(void);
signals:
	void isready(bool);

private:

	KTabCtl *tabctl;
	QPushButton *confOK,*confCancel;
	QWidget *patternPage;
	QWidget *advancePage;
	QWidget *printPage;
	KLined *patternDir_ed,*patternSfx_ed,*advanceDist_ed;
	KConfig *tempconf;
	QCheckBox *patternCopy;
};

#endif // KBLINSELCONFIG_H
